@@ -11,11 +11,13 @@ This module provides
   - a set of basic tasks
 """
 
-from .task import Task
 from .loader import load, loaded_tasks
 
+from .task import Task
+
 from .include import Include
 from .config import Config
+from .context import Context
 from .echo import Echo
 from .chdir import Chdir
 from .command import Command
@@ -24,11 +26,14 @@ from .exit import Exit
 from .file import Copy, Move, Link, Remove, MakeDir
 from .find import Find
 from .template import Template
+from .time import Time
+from .task_timer import TaskTimer
 
 
 def task_loader_map():
     return {'include': Include,
             'config': Config,
+            'context': Context,
             'echo': Echo,
             'chdir': Chdir,
             'command': Command,
@@ -40,4 +45,7 @@ def task_loader_map():
             'remove': Remove,
             'make_dir': MakeDir,
             'find': Find,
-            'template': Template}
+            'template': Template,
+            'time': Time,
+            'task_timer': TaskTimer,
+           }
