@@ -3,7 +3,7 @@
 import os
 
 from scriptengine.tasks.base import Task
-from scriptengine.jinja import render as j2render
+from scriptengine.tasks.base.timing import timed_runner
 
 
 class Chdir(Task):
@@ -12,10 +12,8 @@ class Chdir(Task):
     def __init__(self, parameters):
         super().__init__(__name__, parameters, required_parameters=["path"])
 
-    def __str__(self):
-        return f"Chdir: {self.path}"
-
+    @timed_runner
     def run(self, context):
-        path = j2render(self.path, context)
+        path = self.getarg('path', context)
         self.log_info(f"Change path to {path}")
         os.chdir(path)
