@@ -6,11 +6,10 @@
             args: [-l, -a]
 """
 
-import ast
 import subprocess
 
 from scriptengine.tasks.base import Task
-from scriptengine.jinja import render as j2render
+from scriptengine.tasks.base.timing import timed_runner
 from scriptengine.exceptions import ScriptEngineStopException
 
 
@@ -19,36 +18,30 @@ class Command(Task):
     def __init__(self, parameters):
         super().__init__(__name__, parameters, ["name"])
 
-    def __str__(self):
-        return f"Command: {self.name} {getattr(self, 'args', '')}"
-
+    @timed_runner
     def run(self, context):
         self.log_info(f"{self.name} "
                       f"args={getattr(self, 'args', 'none')} "
                       f"cwd={getattr(self, 'cwd', 'none')}")
 
-        command = j2render(self.name, context)
+        command = self.getarg('name', context)
 
-        args = j2render(str(getattr(self, "args", "")), context) or "[]"
-        try:
-            args = ast.literal_eval(args)
-        except ValueError:
-            args = ast.literal_eval(f'"{args}"')
+        args = self.getarg('args', context, default=[])
         args = args if isinstance(args, list) else [args]
 
-        cwd = j2render(getattr(self, "cwd", ''), context) or None
+        cwd = self.getarg('cwd', context, default=None)
 
         self.log_debug(f"{command} {' '.join(map(str,args))}"
                        f"{' cwd='+cwd if cwd else ''}")
 
-        stdout = getattr(self, "stdout", None)
+        stdout = self.getarg('stdout', default=None)
         try:
             result = subprocess.run(map(str, [command]+args),
                                     stdout=subprocess.PIPE if stdout is not None else None,
                                     cwd=cwd,
                                     check=True)
         except subprocess.CalledProcessError as error:
-            if getattr(self, "ignore_error", False) is True:
+            if self.getarg('ignore_error', context, default=False):
                 self.log_warning(f"{self.name} returned error code {error.returncode}")
             else:
                 self.log_error(f"{self.name} returned error code {error.returncode}")
