@@ -1,7 +1,5 @@
 """Exit task for ScriptEngine."""
 
-import sys
-
 from scriptengine.tasks.base import Task
 from scriptengine.exceptions import ScriptEngineStopException
 
@@ -12,9 +10,7 @@ class Exit(Task):
     def __init__(self, parameters=None):
         super().__init__(__name__, parameters)
 
-    def __str__(self):
-        return f"Exit {getattr(self, 'msg', '')}"
-
     def run(self, context):
-        self.log_info(getattr(self, "msg", "Requesting ScriptEngine to stop"))
+        msg = self.getarg('msg', context, default='Requesting ScriptEngine to stop')
+        self.log_info(msg)
         raise ScriptEngineStopException("Exit task requests stopping ScriptEngine")
