@@ -6,7 +6,7 @@ import os
 import shutil
 
 from scriptengine.tasks.base import Task
-from scriptengine.jinja import render as j2render
+from scriptengine.tasks.base.timing import timed_runner
 
 
 class Copy(Task):
@@ -18,19 +18,20 @@ class Copy(Task):
     def __init__(self, parameters):
         super().__init__(__name__+".copy", parameters, required_parameters=["src", "dst"])
 
+    @timed_runner
     def run(self, context):
-        src_path = j2render(self.src, context)
-        dst_path = j2render(self.dst, context)
-        if os.path.isfile(src_path):
-            self.log_info(f"Copy file: {src_path} --> {dst_path}")
-            if os.path.isfile(dst_path):
-                self.log_warning(f"Destination file '{dst_path}' exists already; overwriting")
-            shutil.copy(src_path, dst_path)
+        src = self.getarg('src', context)
+        dst = self.getarg('dst', context)
+        if os.path.isfile(src):
+            self.log_info(f"Copy file: {src} --> {dst}")
+            if os.path.isfile(dst):
+                self.log_warning(f"Destination file '{dst}' exists already; overwriting")
+            shutil.copy(src, dst)
         else:
-            self.log_info(f"Copy directory: {src_path} --> {dst_path}")
-            if os.path.exists(dst_path):
-                raise RuntimeError(f"Target '{dst_path}' for directory copy exists already")
-            shutil.copytree(src_path, dst_path, symlinks=True)
+            self.log_info(f"Copy directory: {src} --> {dst}")
+            if os.path.exists(dst):
+                raise RuntimeError(f"Target '{dst}' for directory copy exists already")
+            shutil.copytree(src, dst, symlinks=True)
 
 
 class Move(Task):
@@ -41,11 +42,12 @@ class Move(Task):
     def __init__(self, parameters):
         super().__init__(__name__+".move", parameters, required_parameters=["src", "dst"])
 
+    @timed_runner
     def run(self, context):
-        src_path = j2render(self.src, context)
-        dst_path = j2render(self.dst, context)
-        self.log_info(f"Move file: {src_path} --> {dst_path}")
-        shutil.move(src_path, dst_path)
+        src = self.getarg('src', context)
+        dst = self.getarg('dst', context)
+        self.log_info(f"Move file: {src} --> {dst}")
+        shutil.move(src, dst)
 
 
 class Link(Task):
@@ -56,13 +58,14 @@ class Link(Task):
     def __init__(self, parameters):
         super().__init__(__name__+".link", parameters, required_parameters=["src", "dst"])
 
+    @timed_runner
     def run(self, context):
-        src_path = j2render(self.src, context)
-        dst_path = j2render(self.dst, context)
-        self.log_info(f"Create link: {src_path} --> {dst_path}")
-        os.symlink(src_path, dst_path)
-        if not os.path.exists(dst_path):
-            self.log_warning(f"Created dangling symlink: '{dst_path}-->{src_path}'")
+        src = self.getarg('src', context)
+        dst = self.getarg('dst', context)
+        self.log_info(f"Create link: {src} --> {dst}")
+        os.symlink(src, dst)
+        if not os.path.exists(dst):
+            self.log_warning(f"Created dangling symlink: '{dst}-->{src}'")
 
 
 class Remove(Task):
@@ -73,8 +76,9 @@ class Remove(Task):
     def __init__(self, parameters):
         super().__init__(__name__+".remove", parameters, required_parameters=["path"])
 
+    @timed_runner
     def run(self, context):
-        path = j2render(self.path, context)
+        path = self.getarg('path', context)
         if os.path.exists(path):
             if os.path.isdir(path):
                 self.log_info(f"Removing directory '{path}'")
@@ -93,8 +97,9 @@ class MakeDir(Task):
     def __init__(self, parameters):
         super().__init__(__name__+".make_dir", parameters, required_parameters=["path"])
 
+    @timed_runner
     def run(self, context):
-        path = j2render(self.path, context)
+        path = self.getarg('path', context)
         if os.path.isdir(path):
             self.log_info(f"Directory '{path}' exists already.")
         elif os.path.isfile(path):
