@@ -3,7 +3,7 @@
 import os
 
 from scriptengine.tasks.base import Task
-from scriptengine.jinja import render as j2render
+from scriptengine.tasks.base.timing import timed_runner
 
 
 class Getenv(Task):
@@ -15,17 +15,18 @@ class Getenv(Task):
     Args:
         dictionary (dict): Must at least contain the following keys:
             - name: Name of the environment variable
-            - set_cfg: Name of the ScriptEngine config parameter that is set to
+            - set: Name of the ScriptEngine config parameter that is set to
                 the value of the environment variable (if it exists)
     """
     def __init__(self, parameters):
-        super().__init__(__name__, parameters, required_parameters=["name", "set_cfg"])
+        super().__init__(__name__, parameters, required_parameters=["name", "set"])
 
     def __str__(self):
-        return f"Getenv: ENV{self.name} --> {self.set_cfg}"
+        return f"Getenv: ENV{self.name} --> {self.set}"
 
+    @timed_runner
     def run(self, context):
-        self.log_info(f"ENV{self.name} --> {self.set_cfg}")
-        env = os.environ.get(j2render(self.name, context))
+        self.log_info(f"ENV{self.name} --> {self.set}")
+        env = os.environ.get(self.getarg('name', context))
         if env:
-            context[j2render(self.set_cfg, context)] = env
+            context[self.getarg('set', context)] = env
