@@ -9,7 +9,7 @@ import os
 import scriptengine.yaml
 
 from scriptengine.tasks.base import Task
-from scriptengine.jinja import render as j2render
+from scriptengine.tasks.base.timing import timed_runner
 
 
 class Include(Task):
@@ -20,11 +20,12 @@ class Include(Task):
     def __str__(self):
         return f"Include: {self.src}"
 
+    @timed_runner
     def run(self, context):
-        inc_file = j2render(self.src, context)
+        inc_file = self.getarg('src', context)
         self.log_info(f"Include script from {inc_file}")
 
-        search_path = [".", context.get("_se_ocwd", "")] + context.get("_se_filepath", [])
+        search_path = [".", context.get("_se_cmd_cwd", "")] + context.get("_se_filepath", [])
         self.log_debug(f"Searching in path: {search_path}")
         for directory in search_path:
             inc_file_path = os.path.join(directory, inc_file)
@@ -33,11 +34,10 @@ class Include(Task):
                 self.log_debug(f"Found include file at '{inc_file_path}'")
                 break
         else:
-            if getattr(self, "ignore_not_found", False):
+            if self.getarg('ignore_not_found', False):
                 self.log_warning(f"Include file {inc_file} not found.")
                 return
-            else:
-                raise RuntimeError(f"Include file '{inc_file}' not found")
+            raise RuntimeError(f"Include file '{inc_file}' not found")
 
         script = scriptengine.yaml.parse_file(inc_file_path)
 
@@ -48,7 +48,7 @@ class Include(Task):
         try:
             se_instance = context['_se_instance']
         except KeyError:
-            raise RuntimeError(f"ScriptEngine instance not found")
+            raise RuntimeError("ScriptEngine instance not found")
         else:
             self.log_debug(f"Execute script from '{inc_file}'")
             se_instance.run(script, context)
