@@ -1,10 +1,10 @@
 """Template task for ScriptEngine."""
 
 import os
-from itertools import chain
 import jinja2
 
 from scriptengine.tasks.base import Task
+from scriptengine.tasks.base.timing import timed_runner
 from scriptengine.jinja import render as j2render
 from scriptengine.jinja import filters as j2filters
 
@@ -27,10 +27,11 @@ class Template(Task):
     def __str__(self):
         return f"Template: {self.src} --> {self.dst}"
 
+    @timed_runner
     def run(self, context):
-        src_path = j2render(self.src, context)
-        dst_path = j2render(self.dst, context)
-        self.log_info(f"Render {src_path} --> {dst_path}")
+        src = self.getarg('src', context)
+        dst = self.getarg('dst', context)
+        self.log_info(f"Render {src} --> {dst}")
 
         # The template search path:
         #   1. .
@@ -38,18 +39,18 @@ class Template(Task):
         #   3. <ocwd>
         #   4. <ocwd>/templates
         # where <ocwd> is the original working directory at the time when the se script was called
-        search_path = [ '.', 'templates' ]
-        if "_se_ocwd" in context:
-            search_path.extend([context["_se_ocwd"],
-                                os.path.join(context["_se_ocwd"], "templates")])
+        search_path = ['.', 'templates']
+        if "_se_cmd_cwd" in context:
+            search_path.extend([context["_se_cmd_cwd"],
+                                os.path.join(context["_se_cmd_cwd"], "templates")])
         self.log_debug(f"Search path for template: {search_path}")
 
         loader = jinja2.FileSystemLoader(search_path)
         environment = jinja2.Environment(loader=loader)
         for name, function in j2filters().items():
             environment.filters[name] = function
-        template = environment.get_template(src_path)
+        template = environment.get_template(src)
         output_text = j2render(template.render(context), context)
 
-        with open(dst_path, "w") as output_file:
+        with open(dst, "w") as output_file:
             output_file.write(f"{output_text}\n")
