@@ -9,17 +9,50 @@ from scriptengine.jobs import Job
 from scriptengine.exceptions import ScriptEngineStopException
 
 
-def construct_noeval_string(loader, node):
-    value = loader.construct_scalar(node)
-    return f"_noeval_{str(value)}"
-yaml.add_constructor(u"!noeval", construct_noeval_string)
+class NoParseYamlString(str):
+    """This represents a string that should not be YAML-parsed"""
 
 
-def construct_rrule(loader, node):
+class NoParseJinjaString(str):
+    """This represents a string that should not be parsed with Jinja2"""
+
+
+class NoParseString(NoParseYamlString, NoParseJinjaString):
+    """This represents a string that should not be parsed at all, neither YAML
+       or Jinja2"""
+
+
+def string_class_constructor(derived_string_class):
+    """YAML constructor factory. The constructors convert their values to a
+       string and return an object of a specific class (derived from str). The
+       class membership is later used to limit the Jinja2/YAML parsing during
+       the processing of ScriptEngine scripts.
+    """
+    def constructor(loader, node):
+        value = loader.construct_scalar(node)
+        return derived_string_class(str(value))
+    return constructor
+yaml.add_constructor(u'!noparse', string_class_constructor(NoParseString))
+yaml.add_constructor(u'!noparse_yaml', string_class_constructor(NoParseYamlString))
+yaml.add_constructor(u'!noparse_jinja', string_class_constructor(NoParseJinjaString))
+
+
+def rrule_constructor(loader, node):
+    """A YAML constructor that can parse RFC5545 rrules
+    """
     value = loader.construct_scalar(node)
     rrule = dateutil.rrule.rrulestr(value)
     return rrule
-yaml.add_constructor(u"!rrule", construct_rrule)
+yaml.add_constructor(u'!rrule', rrule_constructor)
+
+
+# Deprecated!
+# The use of !noeval is deprecated. Use !noparse or the specific versions
+# !noparse_jinja/!noparse_yaml instead!
+def noeval_string_constructor(loader, node):
+    value = loader.construct_scalar(node)
+    return '_noeval_'+str(value)
+yaml.add_constructor(u'!noeval', noeval_string_constructor)
 
 
 def parse(data):
@@ -33,7 +66,7 @@ def parse(data):
         A scriptengine.task.Task, a scriptengine.jobs.Job, or a list of tasks/jobs.
     """
     tasks = loaded_tasks()
-    jobs  = {"do"}
+    jobs = {"do"}
 
     if not data:
         return []
@@ -53,25 +86,25 @@ def parse(data):
     if not keys:
         raise ScriptEngineStopException(f"Unknown task name in: "
                                         f"{list(data.keys())}")
-    if len(keys)>1:
+    if len(keys) > 1:
         raise ScriptEngineStopException(f"Ambiguous keys in "
                                         f"{list(data.keys())}")
 
     key = keys.pop()
 
     if key in tasks:
-        if len(data)==1: # Simple task (no when clause or loop)
+        if len(data) == 1: # Simple task (no when clause or loop)
             return tasks[key](data[key])
-        else:            # Job made from single task with when/loop
-            job = Job(when=data.get("when"), loop=data.get("loop"))
-            job.append(parse({key: data[key]}))
-            return job
-    else:
+        # Job made from single task with when/loop
         job = Job(when=data.get("when"), loop=data.get("loop"))
-        for item in data[key]:
-            job.append(parse(item))
+        job.append(parse({key: data[key]}))
         return job
 
+    job = Job(when=data.get("when"), loop=data.get("loop"))
+    for item in data[key]:
+        job.append(parse(item))
+    return job
+
 
 def parse_file(filename):
     """Reads a ScriptEngine script from a YAML file.
